==> quanyi-goods-service-api-0.1.46-20251020.071327-25-sources.jar: cn/com/duiba/quanyi/goods/service/api/remoteservice/cardsecret/RemoteCardSecretAssociationTaskService.java <==
package cn.com.duiba.quanyi.goods.service.api.remoteservice.cardsecret;

import java.util.List;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.quanyi.goods.service.api.dto.cardsecret.CardSecretAssociationTaskDto;
import cn.com.duiba.quanyi.goods.service.api.param.cardsecret.CardSecretAssociationReturnParam;
import cn.com.duiba.quanyi.goods.service.api.param.cardsecret.CardSecretAssociationTaskQueryParam;

/**
 * 卡密关联记录远程服务
 *
 * @author yangyukang
 * @date 2024-09-16
 */
@AdvancedFeignClient
public interface RemoteCardSecretAssociationTaskService {


    /**
     * 保存
     *
     * @param dto 参数dto
     * @return 影响行数
     */
    Long insert(CardSecretAssociationTaskDto dto);

    /**
     * 根据主键ID查询
     *
     * @param id 主键ID
     * @return CardSecretAssociationTaskDto
     */
    CardSecretAssociationTaskDto selectById(Long id);


    /**
     * 根据采购单ID查询
     *
     * @param purchaseOrderId 采购单ID
     * @return 关联记录列表
     */
    List<CardSecretAssociationTaskDto> selectByPurchaseOrderId(Long purchaseOrderId);

    /**
     * 根据批次ID查询
     *
     * @param cardSecretBatchId 批次ID
     * @return 关联记录列表
     */
    List<CardSecretAssociationTaskDto> selectByCardSecretBatchId(Long cardSecretBatchId);

    /**
     * 根据需求商品ID查询
     *
     * @param demandGoodsId 需求商品ID
     * @return 关联记录列表
     */
    List<CardSecretAssociationTaskDto> selectByDemandGoodsId(Long demandGoodsId);

    /**
     * 根据状态查询
     *
     * @param status 状态
     * @return 关联记录列表
     */
    List<CardSecretAssociationTaskDto> selectByStatus(Integer status);

    /**
     * 统计行数
     *
     * @param queryParam 查询参数
     * @return 行数
     */
    long selectCount(CardSecretAssociationTaskQueryParam queryParam);

    /**
     * 分页查询
     *
     * @param queryParam 查询参数
     * @return 关联记录列表
     */
    List<CardSecretAssociationTaskDto> selectPage(CardSecretAssociationTaskQueryParam queryParam);

    /**
     * 根据关联任务ID重试
     *
     * @param associationTaskId 关联任务ID
     * @return 影响行数
     */
    Boolean retryAssociationTask(Long associationTaskId) throws BizException;

    /**
     * 线上退回卡密关联任务
     *
     * @param param 退回请求参数
     * @return 是否退回成功
     * @throws BizException 业务异常
     */
    Boolean returnAssociationTask(CardSecretAssociationReturnParam param) throws BizException;
    
    /**
     * 线下退回卡密关联任务
     *
     * @param param 退回请求参数
     * @return 是否退回成功
     * @throws BizException 业务异常
     */
    Boolean offlineReturnAssociationTask(CardSecretAssociationReturnParam param) throws BizException;

}

==> quanyi-goods-service-api-0.1.46-20251020.100645-26-sources.jar: cn/com/duiba/quanyi/goods/service/api/remoteservice/cardsecret/RemoteCardSecretAssociationTaskService.java <==
package cn.com.duiba.quanyi.goods.service.api.remoteservice.cardsecret;

import java.util.List;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.quanyi.goods.service.api.dto.cardsecret.CardSecretAssociationTaskDto;
import cn.com.duiba.quanyi.goods.service.api.param.cardsecret.CardSecretAssociationReturnParam;
import cn.com.duiba.quanyi.goods.service.api.param.cardsecret.CardSecretAssociationTaskQueryParam;

/**
 * 卡密关联记录远程服务
 *
 * @author yangyukang
 * @date 2024-09-16
 */
@AdvancedFeignClient
public interface RemoteCardSecretAssociationTaskService {


    /**
     * 保存
     *
     * @param dto 参数dto
     * @return 影响行数
     */
    Long insert(CardSecretAssociationTaskDto dto);

    /**
     * 根据主键ID查询
     *
     * @param id 主键ID
     * @return CardSecretAssociationTaskDto
     */
    CardSecretAssociationTaskDto selectById(Long id);


    /**
     * 根据采购单ID查询
     *
     * @param purchaseOrderId 采购单ID
     * @return 关联记录列表
     */
    List<CardSecretAssociationTaskDto> selectByPurchaseOrderId(Long purchaseOrderId);

    /**
     * 根据采购单ID集合批量查询
     *
     * @param purchaseOrderIds 采购单ID集合
     * @return 关联记录列表
     */
    List<CardSecretAssociationTaskDto> selectByPurchaseOrderIds(List<Long> purchaseOrderIds);

    /**
     * 根据批次ID查询
     *
     * @param cardSecretBatchId 批次ID
     * @return 关联记录列表
     */
    List<CardSecretAssociationTaskDto> selectByCardSecretBatchId(Long cardSecretBatchId);

    /**
     * 根据需求商品ID查询
     *
     * @param demandGoodsId 需求商品ID
     * @return 关联记录列表
     */
    List<CardSecretAssociationTaskDto> selectByDemandGoodsId(Long demandGoodsId);

    /**
     * 根据状态查询
     *
     * @param status 状态
     * @return 关联记录列表
     */
    List<CardSecretAssociationTaskDto> selectByStatus(Integer status);

    /**
     * 统计行数
     *
     * @param queryParam 查询参数
     * @return 行数
     */
    long selectCount(CardSecretAssociationTaskQueryParam queryParam);

    /**
     * 分页查询
     *
     * @param queryParam 查询参数
     * @return 关联记录列表
     */
    List<CardSecretAssociationTaskDto> selectPage(CardSecretAssociationTaskQueryParam queryParam);

    /**
     * 根据关联任务ID重试
     *
     * @param associationTaskId 关联任务ID
     * @return 影响行数
     */
    Boolean retryAssociationTask(Long associationTaskId) throws BizException;

    /**
     * 线上退回卡密关联任务
     *
     * @param param 退回请求参数
     * @return 是否退回成功
     * @throws BizException 业务异常
     */
    Boolean returnAssociationTask(CardSecretAssociationReturnParam param) throws BizException;
    
    /**
     * 线下退回卡密关联任务
     *
     * @param param 退回请求参数
     * @return 是否退回成功
     * @throws BizException 业务异常
     */
    Boolean offlineReturnAssociationTask(CardSecretAssociationReturnParam param) throws BizException;

}
